# plueprint
[API Blueprint](https://github.com/apiaryio/api-blueprint) parser written in Python.
It uses [Markdown](https://pythonhosted.org/Markdown) well-known package to do
initial DOM parsing.
Currently, not finished. Development plans include:

* Writing a good test suite
* Adding the test generator for Django (as a separate project)

Released under New BSD license.
